@@ -5,9 +5,9 @@
 ;; Author: Feng Shu <tumashu@163.com>
 ;; Maintainer: Feng Shu <tumashu@163.com>
 ;; URL: https://github.com/tumashu/vertico-posframe
-;; Version: 0.8.0
+;; Version: 0.9.0
 ;; Keywords: abbrev, convenience, matching, vertico
-;; Package-Requires: ((emacs "26.0") (posframe "1.4.0") (vertico "1.10"))
+;; Package-Requires: ((emacs "26.0") (posframe "1.4.0") (vertico "2.5"))
 
 ;; This file is part of GNU Emacs.
 
@@ -252,8 +252,8 @@ vertico-posframe works with vertico multiform toggle."
        (setq-local vertico-posframe--use-auto-hscroll-mode-p nil))))
   (posframe-hide vertico-posframe--buffer))
 
-(cl-defmethod vertico--resize
-  (&context ((vertico-posframe-mode-workable-p) (eql t))))
+(cl-defmethod vertico--resize-window
+  (_height &context ((vertico-posframe-mode-workable-p) (eql t))))
 
 (cl-defmethod vertico--display-candidates
   :after (_candidates &context ((vertico-posframe-mode-workable-p) (eql t)))
@@ -307,7 +307,13 @@ vertico-posframe works with vertico multiform toggle."
         (setq-local vertico-posframe--use-auto-hscroll-mode-p t)))
     (apply #'posframe-show
            buffer
-           :cursor 'box
+           :cursor (if (eq cursor-type t)
+                       ;; For vertico-posframe special, when
+                       ;; cursor-type is t, hollow box will be showed,
+                       ;; which is not expected by user, so we should
+                       ;; force show it with box.
+                       'box
+                     cursor-type)
            :tty-non-selected-cursor t
            :window-point window-point
            :font (buffer-local-value 'vertico-posframe-font buffer)
